@@ -27,7 +27,7 @@ class DocumentPlot():
 
         self.path = f"{name}.jpeg"
 
-        if df:
+        if df.empty:
             self.df = df
 
     def add_to(self, section):
